@@ -47,7 +47,7 @@ progress_changed_cb (FlatpakTransactionProgress *progress,
 {
     FlatpakTransactionThread *obj = (FlatpakTransactionThread*) user_data;
 
-    obj->setProgress(flatpak_transaction_progress_get_progress(progress));
+    obj->setProgress(qMin(99, flatpak_transaction_progress_get_progress(progress)));
 
 #ifdef FLATPAK_VERBOSE_PROGRESS
     guint64 start_time = flatpak_transaction_progress_get_start_time (progress);
@@ -155,16 +155,43 @@ void FlatpakTransactionThread::run()
         }
     }
 
-    // We are done so we can set the progress to 100
     m_result = flatpak_transaction_run(m_transaction, m_cancellable, &localError);
     if (!m_result) {
         m_errorMessage = QString::fromUtf8(localError->message);
+#if defined(FLATPAK_LIST_UNUSED_REFS)
+    } else {
+        const auto installation = flatpak_transaction_get_installation(m_transaction);
+        g_autoptr(GPtrArray) refs = flatpak_installation_list_unused_refs(installation, nullptr, m_cancellable, nullptr);
+        if (refs->len > 0) {
+            g_autoptr(GError) localError = nullptr;
+            qDebug() << "found unused refs:" << refs->len;
+            auto transaction = flatpak_transaction_new_for_installation(installation, m_cancellable, &localError);
+            for (uint i = 0; i < refs->len; i++) {
+                FlatpakRef *ref = FLATPAK_REF(g_ptr_array_index(refs, i));
+                g_autofree gchar *strRef = flatpak_ref_format_ref(ref);
+                qDebug() << "unused ref:" << strRef;
+                if (!flatpak_transaction_add_uninstall(transaction,
+                                            strRef,
+                                            &localError))
+                {
+                    qDebug() << "failed to uninstall unused ref" << refName << localError->message;
+                    break;
+                }
+            }
+            if (!flatpak_transaction_run(transaction, m_cancellable, &localError)) {
+                qWarning() << "could not properly clean the elements" << refs->len << localError->message;
+            }
+            g_object_unref(m_transaction);
+        }
+#endif
     }
+    // We are done so we can set the progress to 100
     setProgress(100);
 }
 
 void FlatpakTransactionThread::setProgress(int progress)
 {
+    Q_ASSERT(qBound(0, progress, 100) == progress);
     if (m_progress != progress) {
         m_progress = progress;
         Q_EMIT progressChanged(m_progress);
