@@ -157,7 +157,7 @@ QString errorMessage(PackageKit::Transaction::Error error)
         case PackageKit::Transaction::ErrorInstallRootInvalid:
             return i18n("Install root is invalid");
         case PackageKit::Transaction::ErrorCannotFetchSources:
-            return i18n("Cannot fetch sources");
+            return i18nc("Failed to sync your Linux distro repositories or other sources of packages", "Cannot fetch sources");
         case PackageKit::Transaction::ErrorCancelledPriority:
             return i18n("Canceled priority");
         case PackageKit::Transaction::ErrorUnfinishedTransaction:
@@ -188,7 +188,7 @@ QString restartMessage(PackageKit::Transaction::Restart restart, const QString&
         case PackageKit::Transaction::RestartUnknown:
         case PackageKit::Transaction::RestartNone:
         default:
-            return i18n("A change by '%1' suggests your system to be rebooted.", PackageKit::Daemon::packageName(pkgid));
+            return i18n("A change by '%1' suggests your system to be restarted.", PackageKit::Daemon::packageName(pkgid));
     }
 }
 
@@ -200,7 +200,7 @@ QString restartMessage(PackageKit::Transaction::Restart restart)
         case PackageKit::Transaction::RestartSession:
             return i18n("The session will have to be restarted");
         case PackageKit::Transaction::RestartSystem:
-            return i18n("The system will have to be rebooted.");
+            return i18n("The system will have to be restarted.");
         case PackageKit::Transaction::RestartSecuritySession:
             return i18n("For security, the session will have to be restarted.");
         case PackageKit::Transaction::RestartSecuritySystem:
