@@ -38,6 +38,7 @@
 #include <KConfigGroup>
 
 #include "pk-offline-private.h"
+#include "libdiscover_backend_debug.h"
 
 PackageKitNotifier::PackageKitNotifier(QObject* parent)
     : BackendNotifierModule(parent)
@@ -104,7 +105,7 @@ void PackageKitNotifier::checkOfflineUpdates()
     if (!QFile::exists(QStringLiteral(PK_OFFLINE_RESULTS_FILENAME))) {
         return;
     }
-    qDebug() << "found offline update results at " << PK_OFFLINE_RESULTS_FILENAME;
+    qCDebug(LIBDISCOVER_BACKEND_LOG) << "found offline update results at " << PK_OFFLINE_RESULTS_FILENAME;
 
     KDesktopFile file(QStringLiteral(PK_OFFLINE_RESULTS_FILENAME));
     KConfigGroup group(&file, PK_OFFLINE_RESULTS_GROUP);
@@ -120,7 +121,7 @@ void PackageKitNotifier::checkOfflineUpdates()
         notification->setText(i18n("Offline Updates"));
         notification->setText(i18np("Failed to update %1 package\n%2", "Failed to update %1 packages\n%2",
                                     packages.count(), errorDetails));
-        notification->setActions(QStringList{i18nc("@action:button", "Open Discover")});
+        notification->setActions(QStringList{i18nc("@action:button", "Open Discover"), i18nc("@action:button", "Repair System")});
 
         connect(notification, &KNotification::action1Activated, this, [] () {
             QProcess::startDetached(QStringLiteral("plasma-discover"));
@@ -173,7 +174,7 @@ void PackageKitNotifier::recheckSystemUpdate()
 
 void PackageKitNotifier::setupGetUpdatesTransaction(PackageKit::Transaction* trans)
 {
-    qDebug() << "using..." << trans << trans->tid().path();
+    qCDebug(LIBDISCOVER_BACKEND_LOG) << "using..." << trans << trans->tid().path();
 
     trans->setProperty("normalUpdates", 0);
     trans->setProperty("securityUpdates", 0);
@@ -250,7 +251,7 @@ QProcess* PackageKitNotifier::checkAptVariable(const QString &aptconfig, const Q
 {
     QProcess* process = new QProcess;
     process->start(aptconfig, {QStringLiteral("dump")});
-    connect(process, static_cast<void(QProcess::*)(int)>(&QProcess::finished), this, [func, process, varname](int code) {
+    connect(process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, [func, process, varname](int code) {
         if (code != 0)
             return;
 
@@ -266,7 +267,7 @@ QProcess* PackageKitNotifier::checkAptVariable(const QString &aptconfig, const Q
         }
         func({});
     });
-    connect(process, static_cast<void(QProcess::*)(int)>(&QProcess::finished), process, &QObject::deleteLater);
+    connect(process, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), process, &QObject::deleteLater);
     return process;
 }
 
@@ -314,5 +315,5 @@ void PackageKitNotifier::onRequireRestart(PackageKit::Transaction::Restart type,
 {
     PackageKit::Transaction* t = qobject_cast<PackageKit::Transaction*>(sender());
     t->setProperty("requireRestart", qMax<int>(t->property("requireRestart").toInt(), type));
-    qDebug() << "RESTART" << type << "is required for package" << packageID;
+    qCDebug(LIBDISCOVER_BACKEND_LOG) << "RESTART" << type << "is required for package" << packageID;
 }
